# This file has been generated


build_system = 'AppVeyor'
build_id = '30815759'
build_number = '596'
build_version = '1.0.596'
job_id = 'lyqj21uv1f6jcvra'
job_url = 'https://ci.appveyor.com/project/KyleAltendorf/pm/build/job/lyqj21uv1f6jcvra'
