# This file was automatically generated by sub\epyqlib\epyqlib\cli\generateversion.py
__version_build_time__ = '2020-02-14T23:50:28.585853'

__version__ = '2020.2.4'
__sha__ = '2adb20727073da5ad1cc5e1c94fa2a292b664834'
__revision__ = '2adb20727073da5ad1cc5e1c94fa2a292b664834'
